@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2019 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2020 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -21,8 +21,7 @@
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 TimerManager::TimerManager()
   : nextId(no_timer + 1),
-    queue(),
-    done(false)
+    queue()
 {
 }
 
@@ -64,7 +63,7 @@ TimerManager::TimerId TimerManager::addTimer(
   // Assign an ID and insert it into function storage
   auto id = nextId++;
   auto iter = active.emplace(id, Timer(id, Clock::now() + Duration(msDelay),
-      Duration(msPeriod), std::move(func)));
+      Duration(msPeriod), func));
 
   // Insert a reference to the Timer into ordering queue
   Queue::iterator place = queue.emplace(iter.first->second);
@@ -231,20 +230,13 @@ bool TimerManager::destroy_impl(ScopedLock& lock, TimerMap::iterator i,
 // TimerManager::Timer implementation
 //
 
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-TimerManager::Timer::Timer(TimerId tid)
-  : id(tid),
-    running(false)
-{
-}
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 TimerManager::Timer::Timer(Timer&& r) noexcept
-  : id(std::move(r.id)),
-    next(std::move(r.next)),
-    period(std::move(r.period)),
+  : id(r.id),
+    next(r.next),
+    period(r.period),
     handler(std::move(r.handler)),
-    running(std::move(r.running))
+    running(r.running)
 {
 }
 
@@ -254,7 +246,6 @@ TimerManager::Timer::Timer(TimerId tid, Timestamp tnext, Duration tperiod,
   : id(tid),
     next(tnext),
     period(tperiod),
-    handler(std::move(func)),
-    running(false)
+    handler(func)
 {
 }
