@@ -35,7 +35,7 @@ string Cartridge3EPlusWidget::description()
 {
   ostringstream info;
   size_t size;
-  const uInt8* image = myCart.getImage(size);
+  const ByteBuffer& image = myCart.getImage(size);
   uInt16 numRomBanks = myCart.romBankCount();
   uInt16 numRamBanks = myCart.ramBankCount();
 
@@ -60,7 +60,7 @@ string Cartridge3EPlusWidget::description()
 void Cartridge3EPlusWidget::bankSelect(int& ypos)
 {
   size_t size;
-  const uInt8* image = myCart.getImage(size);
+  const ByteBuffer& image = myCart.getImage(size);
   const int VGAP = myFontHeight / 4;
   VariantList banktype;
 
