@@ -478,20 +478,21 @@ void DebuggerDialog::addStatusArea()
 {
   const int lineHeight = myLFont->getLineHeight();
   const Common::Rect& r = getStatusBounds();
+  const int HBORDER = 10;
+  const int VGAP = lineHeight / 3;
   int xpos, ypos;
 
-  xpos = r.x();  ypos = r.y();
-  myTiaInfo = new TiaInfoWidget(this, *myLFont, *myNFont, xpos, ypos, r.w());
+  xpos = r.x() + HBORDER;  ypos = r.y();
+  myTiaInfo = new TiaInfoWidget(this, *myLFont, *myNFont, xpos, ypos, r.w() - HBORDER);
 
-  ypos += myTiaInfo->getHeight() + 8;
-  myTiaZoom = new TiaZoomWidget(this, *myNFont, xpos + 10, ypos,
-                                r.w() - 10, r.h() - lineHeight - ypos - 3);
+  ypos = myTiaInfo->getBottom() + VGAP;
+  myTiaZoom = new TiaZoomWidget(this, *myNFont, xpos, ypos,
+                                r.w() - HBORDER, r.h() - ypos - VGAP - lineHeight + 3);
   addToFocusList(myTiaZoom->getFocusList());
 
-  xpos += 10;  ypos += myTiaZoom->getHeight() + 6;
-  myMessageBox = new EditTextWidget(this, *myLFont,
-                                    xpos, ypos, myTiaZoom->getWidth(),
-                                    myLFont->getLineHeight(), "");
+  ypos = myTiaZoom->getBottom() + VGAP;
+  myMessageBox = new EditTextWidget(this, *myLFont, xpos, ypos,
+                                    myTiaZoom->getWidth(), lineHeight);
   myMessageBox->setEditable(false, false);
   myMessageBox->clearFlags(Widget::FLAG_RETAIN_FOCUS);
   myMessageBox->setTextColor(kTextColorEm);
@@ -589,7 +590,7 @@ void DebuggerDialog::addRomArea()
   DataGridOpsWidget* ops = new DataGridOpsWidget(this, *myLFont, xpos, ypos);
 
   int max_w = xpos - r.x() - 10;
-  xpos = r.x() + 10;  ypos = 10;
+  xpos = r.x() + 10;  ypos = 5;
   myCpu = new CpuWidget(this, *myLFont, *myNFont, xpos, ypos, max_w);
   addToFocusList(myCpu->getFocusList());
 
