@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2019 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2020 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -37,7 +37,7 @@ DelayQueueWidget::DelayQueueWidget(
   _textcolor = kTextColor;
 
   _w = 20 * font.getMaxCharWidth() + 6;
-  _h = lineCount * font.getLineHeight() + 6;
+  _h = static_cast<int>(myLines.size() * font.getLineHeight() + 6);
 
   for (auto&& line : myLines) line = "";
 }
@@ -52,7 +52,7 @@ void DelayQueueWidget::loadConfig() {
     if (!delayQueueIterator->isValid()) {
       line = "";
       continue;
-    };
+    }
 
     stringstream ss;
     const auto address = delayQueueIterator->address();
@@ -75,7 +75,7 @@ void DelayQueueWidget::loadConfig() {
         if (address < 64) ss
           << delay
           << " clk, $"
-          << Base::toString(delayQueueIterator->value(), Base::Format::F_16_2)
+          << Base::toString(delayQueueIterator->value(), Base::Fmt::_16_2)
           << " -> "
           << instance().debugger().cartDebug().getLabel(address, false);
         break;
