@@ -37,24 +37,27 @@ RamWidget::RamWidget(GuiObject* boss, const GUI::Font& lfont, const GUI::Font& n
     myFontWidth(lfont.getMaxCharWidth()),
     myFontHeight(lfont.getFontHeight()),
     myLineHeight(lfont.getLineHeight()),
-    myButtonHeight(myLineHeight + 4),
+    myButtonHeight(myLineHeight * 1.25),
     myRamSize(ramsize),
     myNumRows(numrows),
     myPageSize(pagesize)
 {
   const int bwidth  = lfont.getStringWidth("Compare " + ELLIPSIS),
             bheight = myLineHeight + 2;
-  const int VGAP = 4;
+  //const int VGAP = 4;
+  const int VGAP = myFontHeight / 4;
+  StaticTextWidget* s;
   WidgetArray wid;
 
   int ypos = y + myLineHeight;
 
   // Add RAM grid (with scrollbar)
   int xpos = x + _font.getStringWidth("xxxx");
+  bool useScrollbar = ramsize / numrows > 16;
   myRamGrid = new DataGridWidget(_boss, _nfont, xpos, ypos,
-                                 16, myNumRows, 2, 8, Common::Base::Fmt::_16, true);
+                                 16, myNumRows, 2, 8, Common::Base::Fmt::_16, useScrollbar);
   myRamGrid->setTarget(this);
-  myRamGrid->setID(kRamHexID);
+  myRamGrid->setID(kRamGridID);
   addFocusWidget(myRamGrid);
 
   // Create actions buttons to the left of the RAM grid
@@ -119,35 +122,43 @@ RamWidget::RamWidget(GuiObject* boss, const GUI::Font& lfont, const GUI::Font& n
 
   // For smaller grids, make sure RAM cell detail fields are below the RESET button
   row = myNumRows < 8 ? 9 : myNumRows + 1;
-  ypos += row * myLineHeight;
+  ypos += (row - 1) * myLineHeight + VGAP * 2;
 
   // We need to define these widgets from right to left since the leftmost
   // one resizes as much as possible
 
   // Add Binary display of selected RAM cell
-  xpos = x + w - 11*myFontWidth - 22;
-  new StaticTextWidget(boss, lfont, xpos, ypos, "Bin");
-  myBinValue = new DataGridWidget(boss, nfont, xpos + 3*myFontWidth + 5, ypos-2,
+  xpos = x + w - 9.6 * myFontWidth - 9;
+  s = new StaticTextWidget(boss, lfont, xpos, ypos, "%");
+  myBinValue = new DataGridWidget(boss, nfont, s->getRight() + myFontWidth * 0.1, ypos-2,
                                   1, 1, 8, 8, Common::Base::Fmt::_2);
   myBinValue->setTarget(this);
   myBinValue->setID(kRamBinID);
 
   // Add Decimal display of selected RAM cell
-  xpos -= 7*myFontWidth + 5 + 20;
-  new StaticTextWidget(boss, lfont, xpos, ypos, "Dec");
-  myDecValue = new DataGridWidget(boss, nfont, xpos + 3*myFontWidth + 5, ypos-2,
+  xpos -= 6.5 * myFontWidth;
+  s = new StaticTextWidget(boss, lfont, xpos, ypos, "#");
+  myDecValue = new DataGridWidget(boss, nfont, s->getRight(), ypos-2,
                                   1, 1, 3, 8, Common::Base::Fmt::_10);
   myDecValue->setTarget(this);
   myDecValue->setID(kRamDecID);
 
+  // Add Hex display of selected RAM cell
+  xpos -= 4.5 * myFontWidth;
+  myHexValue = new DataGridWidget(boss, nfont, xpos, ypos - 2,
+                                  1, 1, 2, 8, Common::Base::Fmt::_16);
+  myHexValue->setTarget(this);
+  myHexValue->setID(kRamHexID);
+
+  addFocusWidget(myHexValue);
   addFocusWidget(myDecValue);
   addFocusWidget(myBinValue);
 
   // Add Label of selected RAM cell
-  int xpos_r = xpos - 20;
+  int xpos_r = xpos - myFontWidth * 1.5;
   xpos = x;
-  new StaticTextWidget(boss, lfont, xpos, ypos, "Label");
-  xpos += 5*myFontWidth + 5;
+  s = new StaticTextWidget(boss, lfont, xpos, ypos, "Label");
+  xpos = s->getRight() + myFontWidth / 2;
   myLabel = new EditTextWidget(boss, nfont, xpos, ypos-2, xpos_r-xpos,
                                myLineHeight);
   myLabel->setEditable(false, true);
@@ -184,11 +195,16 @@ void RamWidget::handleCommand(CommandSender* sender, int cmd, int data, int id)
     {
       switch(id)
       {
-        case kRamHexID:
+        case kRamGridID:
           addr  = myRamGrid->getSelectedAddr();
           value = myRamGrid->getSelectedValue();
           break;
 
+        case kRamHexID:
+          addr  = myRamGrid->getSelectedAddr();
+          value = myHexValue->getSelectedValue();
+          break;
+
         case kRamDecID:
           addr  = myRamGrid->getSelectedAddr();
           value = myDecValue->getSelectedValue();
@@ -210,6 +226,7 @@ void RamWidget::handleCommand(CommandSender* sender, int cmd, int data, int id)
       myUndoValue = oldval;
 
       myRamGrid->setValueInternal(addr - myCurrentRamBank*myPageSize, value, true);
+      myHexValue->setValueInternal(0, value, true);
       myDecValue->setValueInternal(0, value, true);
       myBinValue->setValueInternal(0, value, true);
 
@@ -222,10 +239,12 @@ void RamWidget::handleCommand(CommandSender* sender, int cmd, int data, int id)
     {
       addr  = myRamGrid->getSelectedAddr();
       value = myRamGrid->getSelectedValue();
+      bool changed = myRamGrid->getSelectedChanged();
 
       myLabel->setText(getLabel(addr));
-      myDecValue->setValueInternal(0, value, false);
-      myBinValue->setValueInternal(0, value, false);
+      myHexValue->setValueInternal(0, value, changed);
+      myDecValue->setValueInternal(0, value, changed);
+      myBinValue->setValueInternal(0, value, changed);
       break;
     }
 
@@ -288,6 +307,7 @@ void RamWidget::handleCommand(CommandSender* sender, int cmd, int data, int id)
 void RamWidget::setOpsWidget(DataGridOpsWidget* w)
 {
   myRamGrid->setOpsWidget(w);
+  myHexValue->setOpsWidget(w);
   myBinValue->setOpsWidget(w);
   myDecValue->setOpsWidget(w);
 }
@@ -296,6 +316,13 @@ void RamWidget::setOpsWidget(DataGridOpsWidget* w)
 void RamWidget::loadConfig()
 {
   fillGrid(true);
+
+  int value = myRamGrid->getSelectedValue();
+  bool changed = myRamGrid->getSelectedChanged();
+
+  myHexValue->setValueInternal(0, value, changed);
+  myDecValue->setValueInternal(0, value, changed);
+  myBinValue->setValueInternal(0, value, changed);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -321,10 +348,10 @@ void RamWidget::fillGrid(bool updateOld)
 
   // Update RAM labels
   uInt32 rport = readPort(start), page = rport & 0xf0;
-  char buf[5];  // NOLINT : convert to stringstream
-  std::snprintf(buf, 5, "%04X", rport);
-  buf[2] = buf[3] = 'x';
-  myRamStart->setLabel(buf);
+  string label = Common::Base::toString(rport, Common::Base::Fmt::_16_4);
+
+  label[2] = label[3] = 'x';
+  myRamStart->setLabel(label);
   for(uInt32 row = 0; row < myNumRows; ++row, page += 0x10)
     myRamLabels[row]->setLabel(Common::Base::toString(page>>4, Common::Base::Fmt::_16_1));
 }
