@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2019 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2020 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -43,12 +43,30 @@ TiaWidget::TiaWidget(GuiObject* boss, const GUI::Font& lfont,
             fontHeight = lfont.getFontHeight(),
             lineHeight = lfont.getLineHeight(),
             buttonW = 7 * fontWidth;
-  int xpos = 10, ypos = 10 + lineHeight, buttonX = 0, buttonY = 0;
+  int xpos = 10, ypos = 10, buttonX = 0, buttonY = 0;
   StaticTextWidget* t = nullptr;
   ButtonWidget* b = nullptr;
 
+
+  ////////////////////////////
+  // VSync/VBlank
+  ////////////////////////////
+  buttonX = xpos;  buttonY = ypos;
+  myVSync = new CheckboxWidget(boss, lfont, buttonX, buttonY, "VSync", kVSyncCmd);
+  myVSync->setTarget(this);
+  addFocusWidget(myVSync);
+
+  buttonX += myVSync->getRight() + 15;
+  myVBlank = new CheckboxWidget(boss, lfont, buttonX, buttonY, "VBlank", kVBlankCmd);
+  myVBlank->setTarget(this);
+  addFocusWidget(myVBlank);
+
+  ypos += lineHeight * 2 + 6;
+
   // Color registers
-  const char* const regNames[] = { "COLUP0", "COLUP1", "COLUPF", "COLUBK" };
+  static constexpr std::array<const char*, 4> regNames = {
+    "COLUP0", "COLUP1", "COLUPF", "COLUBK"
+  };
   for(int row = 0; row < 4; ++row)
   {
     new StaticTextWidget(boss, lfont, xpos, ypos + row*lineHeight + 2,
@@ -56,7 +74,7 @@ TiaWidget::TiaWidget(GuiObject* boss, const GUI::Font& lfont,
   }
   xpos += 6*fontWidth + 8;
   myColorRegs = new DataGridWidget(boss, nfont, xpos, ypos,
-                                   1, 4, 2, 8, Common::Base::F_16);
+                                   1, 4, 2, 8, Common::Base::Fmt::_16);
   myColorRegs->setTarget(this);
   myColorRegs->setID(kColorRegsID);
   addFocusWidget(myColorRegs);
@@ -82,12 +100,14 @@ TiaWidget::TiaWidget(GuiObject* boss, const GUI::Font& lfont,
   myCOLUBKColor->setTarget(this);
 
   // Fixed debug colors
-  xpos += myCOLUP0Color->getWidth() + 30;  ypos = 10;
+  xpos += myCOLUP0Color->getWidth() + 30;  ypos = 10 + lineHeight + 6;
   myFixedEnabled = new CheckboxWidget(boss, lfont, xpos, ypos, "Debug Colors", kDbgClCmd);
   myFixedEnabled->setTarget(this);
   addFocusWidget(myFixedEnabled);
 
-  const char* const dbgLabels[] = { "P0", "P1", "PF", "BK", "M0", "M1", "BL", "HM" };
+  static constexpr std::array<const char*, 8> dbgLabels = {
+    "P0", "P1", "PF", "BK", "M0", "M1", "BL", "HM"
+  };
   for(uInt32 row = 0; row <= 3; ++row)
   {
     ypos += lineHeight;
@@ -98,7 +118,7 @@ TiaWidget::TiaWidget(GuiObject* boss, const GUI::Font& lfont,
     myFixedColors[row]->setTarget(this);
   }
   xpos += t->getWidth() + myFixedColors[0]->getWidth() + 24;
-  ypos = 10;
+  ypos = 10 + lineHeight + 6;
   for(uInt32 row = 4; row <= 7; ++row)
   {
     ypos += lineHeight;
@@ -117,8 +137,8 @@ TiaWidget::TiaWidget(GuiObject* boss, const GUI::Font& lfont,
   // Add all 15 collision bits (with labels)
   uInt32 cxclrY = 0;
   xpos -= 2*fontWidth + 5;  ypos += lineHeight;
-  const char* const rowLabel[] = { "P0", "P1", "M0", "M1", "BL" };
-  const char* const colLabel[] = { "PF", "BL", "M1", "M0", "P1" };
+  static constexpr std::array<const char*, 5> rowLabel = { "P0", "P1", "M0", "M1", "BL" };
+  static constexpr std::array<const char*, 5> colLabel = { "PF", "BL", "M1", "M0", "P1" };
   uInt32 lwidth = 2*fontWidth, collX = xpos + lwidth + 5, collY = ypos, idx = 0;
   for(uInt32 row = 0; row < 5; ++row)
   {
@@ -182,7 +202,7 @@ TiaWidget::TiaWidget(GuiObject* boss, const GUI::Font& lfont,
                            "Pos#", TextAlign::Left);
   xpos += t->getWidth() + 2;
   myPosP0 = new DataGridWidget(boss, nfont, xpos, ypos,
-                               1, 1, 3, 8, Common::Base::F_10);
+                               1, 1, 3, 8, Common::Base::Fmt::_10);
   myPosP0->setTarget(this);
   myPosP0->setID(kPosP0ID);
   myPosP0->setRange(0, 160);
@@ -194,7 +214,7 @@ TiaWidget::TiaWidget(GuiObject* boss, const GUI::Font& lfont,
                        "HM", TextAlign::Left);
   xpos += 2*fontWidth + 5;
   myHMP0 = new DataGridWidget(boss, nfont, xpos, ypos,
-                              1, 1, 1, 4, Common::Base::F_16_1);
+                              1, 1, 1, 4, Common::Base::Fmt::_16_1);
   myHMP0->setTarget(this);
   myHMP0->setID(kHMP0ID);
   addFocusWidget(myHMP0);
@@ -237,7 +257,7 @@ TiaWidget::TiaWidget(GuiObject* boss, const GUI::Font& lfont,
                        "NuSiz", TextAlign::Left);
   xpos += 5*fontWidth + 5;
   myNusizP0 = new DataGridWidget(boss, nfont, xpos, ypos,
-                                 1, 1, 1, 3, Common::Base::F_16_1);
+                                 1, 1, 1, 3, Common::Base::Fmt::_16_1);
   myNusizP0->setTarget(this);
   myNusizP0->setID(kNusizP0ID);
   addFocusWidget(myNusizP0);
@@ -267,7 +287,7 @@ TiaWidget::TiaWidget(GuiObject* boss, const GUI::Font& lfont,
                            "Pos#", TextAlign::Left);
   xpos += t->getWidth() + 2;
   myPosP1 = new DataGridWidget(boss, nfont, xpos, ypos,
-                               1, 1, 3, 8, Common::Base::F_10);
+                               1, 1, 3, 8, Common::Base::Fmt::_10);
   myPosP1->setTarget(this);
   myPosP1->setID(kPosP1ID);
   myPosP1->setRange(0, 160);
@@ -279,7 +299,7 @@ TiaWidget::TiaWidget(GuiObject* boss, const GUI::Font& lfont,
                        "HM", TextAlign::Left);
   xpos += 2*fontWidth + 5;
   myHMP1 = new DataGridWidget(boss, nfont, xpos, ypos,
-                              1, 1, 1, 4, Common::Base::F_16_1);
+                              1, 1, 1, 4, Common::Base::Fmt::_16_1);
   myHMP1->setTarget(this);
   myHMP1->setID(kHMP1ID);
   addFocusWidget(myHMP1);
@@ -321,7 +341,7 @@ TiaWidget::TiaWidget(GuiObject* boss, const GUI::Font& lfont,
                        "NuSiz", TextAlign::Left);
   xpos += 5*fontWidth + 5;
   myNusizP1 = new DataGridWidget(boss, nfont, xpos, ypos,
-                                 1, 1, 1, 3, Common::Base::F_16_1);
+                                 1, 1, 1, 3, Common::Base::Fmt::_16_1);
   myNusizP1->setTarget(this);
   myNusizP1->setID(kNusizP1ID);
   addFocusWidget(myNusizP1);
@@ -351,7 +371,7 @@ TiaWidget::TiaWidget(GuiObject* boss, const GUI::Font& lfont,
                            "Pos#", TextAlign::Left);
   xpos += t->getWidth() + 2;
   myPosM0 = new DataGridWidget(boss, nfont, xpos, ypos,
-                               1, 1, 3, 8, Common::Base::F_10);
+                               1, 1, 3, 8, Common::Base::Fmt::_10);
   myPosM0->setTarget(this);
   myPosM0->setID(kPosM0ID);
   myPosM0->setRange(0, 160);
@@ -363,7 +383,7 @@ TiaWidget::TiaWidget(GuiObject* boss, const GUI::Font& lfont,
                        "HM", TextAlign::Left);
   xpos += 2*fontWidth + 5;
   myHMM0 = new DataGridWidget(boss, nfont, xpos, ypos,
-                              1, 1, 1, 4, Common::Base::F_16_1);
+                              1, 1, 1, 4, Common::Base::Fmt::_16_1);
   myHMM0->setTarget(this);
   myHMM0->setID(kHMM0ID);
   addFocusWidget(myHMM0);
@@ -374,7 +394,7 @@ TiaWidget::TiaWidget(GuiObject* boss, const GUI::Font& lfont,
                        "Size", TextAlign::Left);
   xpos += 4*fontWidth + 5;
   myNusizM0 = new DataGridWidget(boss, nfont, xpos, ypos,
-                                 1, 1, 1, 2, Common::Base::F_16_1);
+                                 1, 1, 1, 2, Common::Base::Fmt::_16_1);
   myNusizM0->setTarget(this);
   myNusizM0->setID(kNusizM0ID);
   addFocusWidget(myNusizM0);
@@ -414,7 +434,7 @@ TiaWidget::TiaWidget(GuiObject* boss, const GUI::Font& lfont,
                            "Pos#", TextAlign::Left);
   xpos += t->getWidth() + 2;
   myPosM1 = new DataGridWidget(boss, nfont, xpos, ypos,
-                               1, 1, 3, 8, Common::Base::F_10);
+                               1, 1, 3, 8, Common::Base::Fmt::_10);
   myPosM1->setTarget(this);
   myPosM1->setID(kPosM1ID);
   myPosM1->setRange(0, 160);
@@ -426,7 +446,7 @@ TiaWidget::TiaWidget(GuiObject* boss, const GUI::Font& lfont,
                        "HM", TextAlign::Left);
   xpos += 2*fontWidth + 5;
   myHMM1 = new DataGridWidget(boss, nfont, xpos, ypos,
-                              1, 1, 1, 4, Common::Base::F_16_1);
+                              1, 1, 1, 4, Common::Base::Fmt::_16_1);
   myHMM1->setTarget(this);
   myHMM1->setID(kHMM1ID);
   addFocusWidget(myHMM1);
@@ -437,7 +457,7 @@ TiaWidget::TiaWidget(GuiObject* boss, const GUI::Font& lfont,
                        "Size", TextAlign::Left);
   xpos += 4*fontWidth + 5;
   myNusizM1 = new DataGridWidget(boss, nfont, xpos, ypos,
-                                 1, 1, 1, 2, Common::Base::F_16_1);
+                                 1, 1, 1, 2, Common::Base::Fmt::_16_1);
   myNusizM1->setTarget(this);
   myNusizM1->setID(kNusizM1ID);
   addFocusWidget(myNusizM1);
@@ -477,7 +497,7 @@ TiaWidget::TiaWidget(GuiObject* boss, const GUI::Font& lfont,
                            "Pos#", TextAlign::Left);
   xpos += t->getWidth() + 2;
   myPosBL = new DataGridWidget(boss, nfont, xpos, ypos,
-                               1, 1, 3, 8, Common::Base::F_10);
+                               1, 1, 3, 8, Common::Base::Fmt::_10);
   myPosBL->setTarget(this);
   myPosBL->setID(kPosBLID);
   myPosBL->setRange(0, 160);
@@ -489,7 +509,7 @@ TiaWidget::TiaWidget(GuiObject* boss, const GUI::Font& lfont,
                        "HM", TextAlign::Left);
   xpos += 2*fontWidth + 5;
   myHMBL = new DataGridWidget(boss, nfont, xpos, ypos,
-                              1, 1, 1, 4, Common::Base::F_16_1);
+                              1, 1, 1, 4, Common::Base::Fmt::_16_1);
   myHMBL->setTarget(this);
   myHMBL->setID(kHMBLID);
   addFocusWidget(myHMBL);
@@ -500,7 +520,7 @@ TiaWidget::TiaWidget(GuiObject* boss, const GUI::Font& lfont,
                        "Size", TextAlign::Left);
   xpos += 4*fontWidth + 5;
   mySizeBL = new DataGridWidget(boss, nfont, xpos, ypos,
-                                1, 1, 1, 2, Common::Base::F_16_1);
+                                1, 1, 1, 2, Common::Base::Fmt::_16_1);
   mySizeBL->setTarget(this);
   mySizeBL->setID(kSizeBLID);
   addFocusWidget(mySizeBL);
@@ -534,7 +554,9 @@ TiaWidget::TiaWidget(GuiObject* boss, const GUI::Font& lfont,
   const GUI::Font& sf = instance().frameBuffer().smallFont();
   const int sfWidth = sf.getMaxCharWidth(),
             sfHeight = sf.getFontHeight();
-  const char* const bitNames[] = { "0", "1", "2", "3", "4", "5", "6", "7" };
+  static constexpr std::array<const char*, 8> bitNames = {
+    "0", "1", "2", "3", "4", "5", "6", "7"
+  };
 
   // PF0
   xpos = 10;  ypos += lineHeight + sfHeight + 6;
@@ -610,7 +632,7 @@ TiaWidget::TiaWidget(GuiObject* boss, const GUI::Font& lfont,
   addFocusWidget(myPriorityPF);
 
   xpos = 10;
-  ypos += 2 * lineHeight;
+  ypos += lineHeight + 10;
   t = new StaticTextWidget(boss, lfont, xpos, ypos, 13*fontWidth, fontHeight,
     "Queued Writes", TextAlign::Left);
 
@@ -633,7 +655,8 @@ TiaWidget::TiaWidget(GuiObject* boss, const GUI::Font& lfont,
   b->setTarget(this);
   addFocusWidget(b);
 
-  buttonY += lineHeight + 3;
+  buttonX = b->getRight() + 20;
+  buttonY = ypos;
   b = new ButtonWidget(boss, lfont, buttonX, buttonY, buttonW, lineHeight,
                        "HMOVE", kHmoveCmd);
   b->setTarget(this);
@@ -698,6 +721,14 @@ void TiaWidget::handleCommand(CommandSender* sender, int cmd, int data, int id)
       myFixedEnabled->setState(tia.tia().toggleFixedColors());
       break;
 
+    case kVSyncCmd:
+      tia.vsync((tia.vsyncAsInt() & ~0x02) | (myVSync->getState() ? 0x02 : 0x00));
+      break;
+
+    case kVBlankCmd:
+      tia.vblank((tia.vblankAsInt() & ~0x02) | (myVBlank->getState() ? 0x02 : 0x00));
+      break;
+
     case DataGridWidget::kItemDataChangedCmd:
       switch(id)
       {
@@ -819,6 +850,9 @@ void TiaWidget::handleCommand(CommandSender* sender, int cmd, int data, int id)
         case kPF2ID:
           tia.pf2(myPF[2]->getIntState());
           break;
+
+        default:
+          break;
       }
       break;
 
@@ -922,8 +956,14 @@ void TiaWidget::handleCommand(CommandSender* sender, int cmd, int data, int id)
         case kPriorityPFID:
           tia.priorityPF(myPriorityPF->getState() ? 1 : 0);
           break;
+
+        default:
+          break;
       }
       break;
+
+    default:
+      break;
   }
 }
 
@@ -1003,22 +1043,24 @@ void TiaWidget::loadConfig()
     myGRP0Old->setColor(kBGColorLo);
     myGRP0Old->setCrossed(true);
   }
-  myGRP0->setIntState(state.gr[P0], false);
-  myGRP0Old->setIntState(state.gr[P0+2], false);
+  myGRP0->setIntState(state.gr[TiaState::P0], false);
+  myGRP0Old->setIntState(state.gr[TiaState::P0+2], false);
 
   // posP0
-  myPosP0->setList(0, state.pos[P0], state.pos[P0] != oldstate.pos[P0]);
+  myPosP0->setList(0, state.pos[TiaState::P0],
+      state.pos[TiaState::P0] != oldstate.pos[TiaState::P0]);
 
   // hmP0
-  myHMP0->setList(0, state.hm[P0], state.hm[P0] != oldstate.hm[P0]);
+  myHMP0->setList(0, state.hm[TiaState::P0],
+      state.hm[TiaState::P0] != oldstate.hm[TiaState::P0]);
 
   // refP0 & vdelP0
-  myRefP0->setState(tia.refP0(), state.ref[P0] != oldstate.ref[P0]);
-  myDelP0->setState(tia.vdelP0(), state.vdel[P0] != oldstate.vdel[P0]);
+  myRefP0->setState(tia.refP0(), state.ref[TiaState::P0] != oldstate.ref[TiaState::P0]);
+  myDelP0->setState(tia.vdelP0(), state.vdel[TiaState::P0] != oldstate.vdel[TiaState::P0]);
 
   // NUSIZ0 (player portion)
-  bool nusiz0changed = state.size[P0] != oldstate.size[P0];
-  myNusizP0->setList(0, state.size[P0], nusiz0changed);
+  bool nusiz0changed = state.size[TiaState::P0] != oldstate.size[TiaState::P0];
+  myNusizP0->setList(0, state.size[TiaState::P0], nusiz0changed);
   myNusizP0Text->setText(tia.nusizP0String(), nusiz0changed);
 
   ////////////////////////////
@@ -1037,22 +1079,24 @@ void TiaWidget::loadConfig()
     myGRP1Old->setColor(kBGColorLo);
     myGRP1Old->setCrossed(true);
   }
-  myGRP1->setIntState(state.gr[P1], false);
-  myGRP1Old->setIntState(state.gr[P1+2], false);
+  myGRP1->setIntState(state.gr[TiaState::P1], false);
+  myGRP1Old->setIntState(state.gr[TiaState::P1+2], false);
 
   // posP1
-  myPosP1->setList(0, state.pos[P1], state.pos[P1] != oldstate.pos[P1]);
+  myPosP1->setList(0, state.pos[TiaState::P1],
+      state.pos[TiaState::P1] != oldstate.pos[TiaState::P1]);
 
   // hmP1
-  myHMP1->setList(0, state.hm[P1], state.hm[P1] != oldstate.hm[P1]);
+  myHMP1->setList(0, state.hm[TiaState::P1],
+      state.hm[TiaState::P1] != oldstate.hm[TiaState::P1]);
 
   // refP1 & vdelP1
-  myRefP1->setState(tia.refP1(), state.ref[P1] != oldstate.ref[P1]);
-  myDelP1->setState(tia.vdelP1(), state.vdel[P1] != oldstate.vdel[P1]);
+  myRefP1->setState(tia.refP1(), state.ref[TiaState::P1] != oldstate.ref[TiaState::P1]);
+  myDelP1->setState(tia.vdelP1(), state.vdel[TiaState::P1] != oldstate.vdel[TiaState::P1]);
 
   // NUSIZ1 (player portion)
-  bool nusiz1changed = state.size[P1] != oldstate.size[P1];
-  myNusizP1->setList(0, state.size[P1], nusiz1changed);
+  bool nusiz1changed = state.size[TiaState::P1] != oldstate.size[TiaState::P1];
+  myNusizP1->setList(0, state.size[TiaState::P1], nusiz1changed);
   myNusizP1Text->setText(tia.nusizP1String(), nusiz1changed);
 
   ////////////////////////////
@@ -1063,16 +1107,19 @@ void TiaWidget::loadConfig()
   myEnaM0->setIntState(tia.enaM0() ? 1 : 0, false);
 
   // posM0
-  myPosM0->setList(0, state.pos[M0], state.pos[M0] != oldstate.pos[M0]);
+  myPosM0->setList(0, state.pos[TiaState::M0],
+      state.pos[TiaState::M0] != oldstate.pos[TiaState::M0]);
 
   // hmM0
-  myHMM0->setList(0, state.hm[M0], state.hm[M0] != oldstate.hm[M0]);
+  myHMM0->setList(0, state.hm[TiaState::M0],
+      state.hm[TiaState::M0] != oldstate.hm[TiaState::M0]);
 
   // NUSIZ0 (missile portion)
-  myNusizM0->setList(0, state.size[M0], state.size[M0] != oldstate.size[M0]);
+  myNusizM0->setList(0, state.size[TiaState::M0],
+      state.size[TiaState::M0] != oldstate.size[TiaState::M0]);
 
   // resMP0
-  myResMP0->setState(tia.resMP0(), state.res[P0] != oldstate.res[P0]);
+  myResMP0->setState(tia.resMP0(), state.res[TiaState::P0] != oldstate.res[TiaState::P0]);
 
   ////////////////////////////
   // M1 register info
@@ -1082,16 +1129,19 @@ void TiaWidget::loadConfig()
   myEnaM1->setIntState(tia.enaM1() ? 1 : 0, false);
 
   // posM1
-  myPosM1->setList(0, state.pos[M1], state.pos[M1] != oldstate.pos[M1]);
+  myPosM1->setList(0, state.pos[TiaState::M1],
+      state.pos[TiaState::M1] != oldstate.pos[TiaState::M1]);
 
   // hmM1
-  myHMM1->setList(0, state.hm[M1], state.hm[M1] != oldstate.hm[M1]);
+  myHMM1->setList(0, state.hm[TiaState::M1],
+      state.hm[TiaState::M1] != oldstate.hm[TiaState::M1]);
 
   // NUSIZ1 (missile portion)
-  myNusizM1->setList(0, state.size[M1], state.size[M1] != oldstate.size[M1]);
+  myNusizM1->setList(0, state.size[TiaState::M1],
+      state.size[TiaState::M1] != oldstate.size[TiaState::M1]);
 
   // resMP1
-  myResMP1->setState(tia.resMP1(),state.res[P1] != oldstate.res[P1]);
+  myResMP1->setState(tia.resMP1(),state.res[TiaState::P1] != oldstate.res[TiaState::P1]);
 
   ////////////////////////////
   // BL register info
@@ -1113,13 +1163,16 @@ void TiaWidget::loadConfig()
   myEnaBLOld->setIntState(state.gr[5], false);
 
   // posBL
-  myPosBL->setList(0, state.pos[BL], state.pos[BL] != oldstate.pos[BL]);
+  myPosBL->setList(0, state.pos[TiaState::BL],
+      state.pos[TiaState::BL] != oldstate.pos[TiaState::BL]);
 
   // hmBL
-  myHMBL->setList(0, state.hm[BL], state.hm[BL] != oldstate.hm[BL]);
+  myHMBL->setList(0, state.hm[TiaState::BL],
+      state.hm[TiaState::BL] != oldstate.hm[TiaState::BL]);
 
   // CTRLPF (size portion)
-  mySizeBL->setList(0, state.size[BL], state.size[BL] != oldstate.size[BL]);
+  mySizeBL->setList(0, state.size[TiaState::BL],
+      state.size[TiaState::BL] != oldstate.size[TiaState::BL]);
 
   // vdelBL
   myDelBL->setState(tia.vdelBL(), state.vdel[2] != oldstate.vdel[2]);
@@ -1149,6 +1202,9 @@ void TiaWidget::loadConfig()
   myPriorityPF->setState(tia.priorityPF(), state.pf[5] != oldstate.pf[5]);
 
   myDelayQueueWidget->loadConfig();
+
+  myVSync->setState(tia.vsync(), tia.vsync() != oldstate.vsb[0]);
+  myVBlank->setState(tia.vblank(), tia.vblank() != oldstate.vsb[1]);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -1178,5 +1234,8 @@ void TiaWidget::changeColorRegs()
       instance().debugger().tiaDebug().coluBK(value);
       myCOLUBKColor->setColor(value);
       break;
+
+    default:
+      break;
   }
 }
