@@ -15,6 +15,7 @@
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //============================================================================
 
+#include "FSNode.hxx"
 #include "Settings.hxx"
 #include "System.hxx"
 #include "MD5.hxx"
@@ -52,19 +53,24 @@ void Cartridge::setAbout(const string& about, const string& type,
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool Cartridge::saveROM(ofstream& out) const
+bool Cartridge::saveROM(const FilesystemNode& out) const
 {
-  size_t size = 0;
-
-  const uInt8* image = getImage(size);
-  if(image == nullptr || size == 0)
+  try
+  {
+    size_t size = 0;
+    const ByteBuffer& image = getImage(size);
+    if(size == 0)
+    {
+      cerr << "save not supported" << endl;
+      return false;
+    }
+    out.write(image, size);
+  }
+  catch(...)
   {
-    cerr << "save not supported" << endl;
     return false;
   }
 
-  out.write(reinterpret_cast<const char*>(image), size);
-
   return true;
 }
 
