@@ -29,17 +29,18 @@
 CartridgeDPCPlus::CartridgeDPCPlus(const ByteBuffer& image, size_t size,
                                    const string& md5, const Settings& settings)
   : Cartridge(settings, md5),
-    mySize(std::min(size, myImage.size()))
+    myImage(make_unique<uInt8[]>(32_KB)),
+    mySize(std::min(size, 32_KB))
 {
-  // Image is always 32K, but in the case of ROM > 29K, the image is
+  // Image is always 32K, but in the case of ROM < 32K, the image is
   // copied to the end of the buffer
-  if(mySize < myImage.size())
-    myImage.fill(0);
-  std::copy_n(image.get(), size, myImage.begin() + (myImage.size() - mySize));
+  if(mySize < 32_KB)
+    std::fill_n(myImage.get(), mySize, 0);
+  std::copy_n(image.get(), size, myImage.get() + (32_KB - mySize));
   createRomAccessArrays(24_KB);
 
   // Pointer to the program ROM (24K @ 3K offset; ignore first 3K)
-  myProgramImage = myImage.data() + 3_KB;
+  myProgramImage = myImage.get() + 3_KB;
 
   // Pointer to the display RAM
   myDisplayImage = myDPCRAM.data() + 3_KB;
@@ -50,9 +51,12 @@ CartridgeDPCPlus::CartridgeDPCPlus(const ByteBuffer& image, size_t size,
   // Create Thumbulator ARM emulator
   bool devSettings = settings.getBool("dev.settings");
   myThumbEmulator = make_unique<Thumbulator>
-      (reinterpret_cast<uInt16*>(myImage.data()),
+      (reinterpret_cast<uInt16*>(myImage.get()),
        reinterpret_cast<uInt16*>(myDPCRAM.data()),
-       static_cast<uInt32>(myImage.size()),
+       static_cast<uInt32>(32_KB),
+      0x00000C00,
+      0x00000C08,
+      0x40001FDC,
        devSettings ? settings.getBool("dev.thumb.trapfatal") : false,
        Thumbulator::ConfigureFor::DPCplus,
        this);
@@ -640,10 +644,10 @@ bool CartridgeDPCPlus::patch(uInt16 address, uInt8 value)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-const uInt8* CartridgeDPCPlus::getImage(size_t& size) const
+const ByteBuffer& CartridgeDPCPlus::getImage(size_t& size) const
 {
   size = mySize;
-  return myImage.data() + (myImage.size() - mySize);
+  return myImage;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
