@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2019 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2020 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -19,7 +19,7 @@
 #include "CartE78K.hxx"
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-CartridgeE78K::CartridgeE78K(const BytePtr& image, uInt32 size,
+CartridgeE78K::CartridgeE78K(const ByteBuffer& image, size_t size,
                              const string& md5, const Settings& settings)
   : CartridgeMNetwork(image, size, md5, settings)
 {
