@@ -110,7 +110,7 @@ string Controller::getName(const Type type)
     "AmigaMouse", "AtariMouse", "AtariVox", "BoosterGrip", "CompuMate",
     "Driving", "Sega Genesis", "Joystick", "Keyboard", "KidVid", "MindLink",
     "Paddles", "Paddles_IAxis", "Paddles_IAxDr", "SaveKey", "TrakBall",
-    "Lightgun"
+    "Lightgun", "QuadTari"
   };
 
   return NAMES[int(type)];
@@ -125,7 +125,7 @@ string Controller::getPropName(const Type type)
     "AMIGAMOUSE", "ATARIMOUSE", "ATARIVOX", "BOOSTERGRIP", "COMPUMATE",
     "DRIVING", "GENESIS", "JOYSTICK", "KEYBOARD", "KIDVID", "MINDLINK",
     "PADDLES", "PADDLES_IAXIS", "PADDLES_IAXDR", "SAVEKEY", "TRAKBALL",
-    "LIGHTGUN"
+    "LIGHTGUN", "QUADTARI"
   };
 
   return PROP_NAMES[int(type)];
@@ -147,3 +147,14 @@ Controller::Type Controller::getType(const string& propName)
 
   return Type::Unknown;
 }
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void Controller::setAutoFireRate(int rate, bool isNTSC)
+{
+  rate = BSPF::clamp(rate, 0, isNTSC ? 30 : 25);
+  AUTO_FIRE_RATE = 32 * 1024 * rate / (isNTSC ? 60 : 50);
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+int Controller::AUTO_FIRE_RATE = 0;
+
