@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2019 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2020 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -31,12 +31,7 @@ namespace {
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 EmulationTiming::EmulationTiming(FrameLayout frameLayout, ConsoleTiming consoleTiming) :
   myFrameLayout(frameLayout),
-  myConsoleTiming(consoleTiming),
-  myPlaybackRate(44100),
-  myPlaybackPeriod(512),
-  myAudioQueueExtraFragments(1),
-  myAudioQueueHeadroom(2),
-  mySpeedFactor(1)
+  myConsoleTiming(consoleTiming)
 {
   recalculate();
 }
@@ -98,7 +93,7 @@ EmulationTiming& EmulationTiming::updateAudioQueueHeadroom(uInt32 audioQueueHead
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 EmulationTiming& EmulationTiming::updateSpeedFactor(float speedFactor)
 {
-  mySpeedFactor = speedFactor;
+  mySpeedFactor = static_cast<double>(speedFactor);
   recalculate();
 
   return *this;
