@@ -377,7 +377,9 @@ AdjustFunction EventHandler::cycleAdjustSetting(int direction)
         #ifdef ADAPTABLE_REFRESH_SUPPORT
           || (myAdjustSetting == AdjustSetting::ADAPT_REFRESH && !isFullScreen)
         #endif
-          || (myAdjustSetting == AdjustSetting::PALETTE_PHASE && !isCustomPalette)
+          || (myAdjustSetting >= AdjustSetting::PALETTE_PHASE
+              && myAdjustSetting <= AdjustSetting::PALETTE_BLUE_SHIFT
+              && !isCustomPalette)
           || (myAdjustSetting >= AdjustSetting::NTSC_SHARPNESS
               && myAdjustSetting <= AdjustSetting::NTSC_BLEEDING
               && !isCustomFilter);
@@ -411,7 +413,7 @@ AdjustFunction EventHandler::getAdjustSetting(AdjustSetting setting)
   {
     // Audio & Video settings
     std::bind(&Sound::adjustVolume, &myOSystem.sound(), _1),
-    std::bind(&FrameBuffer::selectVidMode, &myOSystem.frameBuffer(), _1),
+    std::bind(&FrameBuffer::switchVideoMode, &myOSystem.frameBuffer(), _1),
     std::bind(&FrameBuffer::toggleFullscreen, &myOSystem.frameBuffer(), _1),
   #ifdef ADAPTABLE_REFRESH_SUPPORT
     std::bind(&FrameBuffer::toggleAdaptRefresh, &myOSystem.frameBuffer(), _1),
@@ -425,6 +427,18 @@ AdjustFunction EventHandler::getAdjustSetting(AdjustSetting setting)
     std::bind(&PaletteHandler::cyclePalette, &myOSystem.frameBuffer().tiaSurface().paletteHandler(), _1),
     std::bind(&PaletteHandler::changeAdjustable, &myOSystem.frameBuffer().tiaSurface().paletteHandler(),
       PaletteHandler::PHASE_SHIFT, _1),
+    std::bind(&PaletteHandler::changeAdjustable, &myOSystem.frameBuffer().tiaSurface().paletteHandler(),
+      PaletteHandler::RED_SCALE, _1),
+    std::bind(&PaletteHandler::changeAdjustable, &myOSystem.frameBuffer().tiaSurface().paletteHandler(),
+      PaletteHandler::RED_SHIFT, _1),
+    std::bind(&PaletteHandler::changeAdjustable, &myOSystem.frameBuffer().tiaSurface().paletteHandler(),
+      PaletteHandler::GREEN_SCALE, _1),
+    std::bind(&PaletteHandler::changeAdjustable, &myOSystem.frameBuffer().tiaSurface().paletteHandler(),
+      PaletteHandler::GREEN_SHIFT, _1),
+    std::bind(&PaletteHandler::changeAdjustable, &myOSystem.frameBuffer().tiaSurface().paletteHandler(),
+      PaletteHandler::BLUE_SCALE, _1),
+    std::bind(&PaletteHandler::changeAdjustable, &myOSystem.frameBuffer().tiaSurface().paletteHandler(),
+      PaletteHandler::BLUE_SHIFT, _1),
     std::bind(&PaletteHandler::changeAdjustable, &myOSystem.frameBuffer().tiaSurface().paletteHandler(),
       PaletteHandler::HUE, _1),
     std::bind(&PaletteHandler::changeAdjustable, &myOSystem.frameBuffer().tiaSurface().paletteHandler(),
@@ -693,7 +707,7 @@ void EventHandler::handleEvent(Event::Type event, Int32 value, bool repeated)
     case Event::VidmodeDecrease:
       if(pressed)
       {
-        myOSystem.frameBuffer().selectVidMode(-1);
+        myOSystem.frameBuffer().switchVideoMode(-1);
         myAdjustSetting = AdjustSetting::ZOOM;
         myAdjustActive = true;
       }
@@ -702,7 +716,7 @@ void EventHandler::handleEvent(Event::Type event, Int32 value, bool repeated)
     case Event::VidmodeIncrease:
       if(pressed)
       {
-        myOSystem.frameBuffer().selectVidMode(+1);
+        myOSystem.frameBuffer().switchVideoMode(+1);
         myAdjustSetting = AdjustSetting::ZOOM;
         myAdjustActive = true;
       }
