@@ -25,6 +25,7 @@
 #include "Settings.hxx"
 #include "TIA.hxx"
 #include "Sound.hxx"
+#include "MediaFactory.hxx"
 
 #include "FBSurface.hxx"
 #include "TIASurface.hxx"
@@ -63,14 +64,24 @@ FrameBuffer::FrameBuffer(OSystem& osystem)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 FrameBuffer::~FrameBuffer()
 {
+  // Make sure to free surfaces/textures before destroying the backend itself
+  // Most platforms are fine with doing this in either order, but it seems
+  // that OpenBSD in particular crashes when attempting to destroy textures
+  // *after* the renderer is already destroyed
+  freeSurfaces();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool FrameBuffer::initialize()
+void FrameBuffer::initialize()
 {
+  // First create the platform-specific backend; it is needed before anything
+  // else can be used
+  try { myBackend = MediaFactory::createVideoBackend(myOSystem); }
+  catch(const runtime_error& e) { throw e; }
+
   // Get desktop resolution and supported renderers
   vector<Common::Size> windowedDisplays;
-  queryHardware(myFullscreenDisplays, windowedDisplays, myRenderers);
+  myBackend->queryHardware(myFullscreenDisplays, windowedDisplays, myRenderers);
   uInt32 query_w = windowedDisplays[0].w, query_h = windowedDisplays[0].h;
 
   // Check the 'maxres' setting, which is an undocumented developer feature
@@ -104,9 +115,11 @@ bool FrameBuffer::initialize()
 #endif
 
   // Determine possible TIA windowed zoom levels
-  myTIAMaxZoom = maxZoomForScreen(
-      TIAConstants::viewableWidth, TIAConstants::viewableHeight,
-      myAbsDesktopSize.w, myAbsDesktopSize.h);
+  myTIAMaxZoom = maxWindowZoom(TIAConstants::viewableWidth,
+                               TIAConstants::viewableHeight);
+  float currentTIAZoom = myOSystem.settings().getFloat("tia.zoom");
+  myOSystem.settings().setValue("tia.zoom",
+      BSPF::clampw(currentTIAZoom, supportedTIAMinZoom(), myTIAMaxZoom));
 
   setUIPalette();
 
@@ -114,8 +127,6 @@ bool FrameBuffer::initialize()
 
   // Create a TIA surface; we need it for rendering TIA images
   myTIASurface = make_unique<TIASurface>(myOSystem);
-
-  return true;
 }
 
 #ifdef GUI_SUPPORT
@@ -173,13 +184,13 @@ void FrameBuffer::setupFonts()
     //  However, we have to make sure all Dialogs are sized using the fontsize.
     int zoom_h = (fd.height * 4 * 2) / GUI::stellaMediumDesc.height;
     int zoom_w = (fd.maxwidth * 4 * 2) / GUI::stellaMediumDesc.maxwidth;
-    myTIAMinZoom = std::max(std::max(zoom_w, zoom_h) / 4.F, 2.F); // round to 25% steps, >= 200%
+    // round to 25% steps, >= 200%
+    myTIAMinZoom = std::max(std::max(zoom_w, zoom_h) / 4.F, 2.F);
   }
 
   // The font used by the ROM launcher
   const string& lf = myOSystem.settings().getString("launcherfont");
 
-
   myLauncherFont = make_unique<GUI::Font>(getFontDesc(lf));       //  8x13
 }
 
@@ -205,21 +216,16 @@ FontDesc FrameBuffer::getFontDesc(const string& name) const
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 FBInitStatus FrameBuffer::createDisplay(const string& title, BufferType type,
-                                        uInt32 width, uInt32 height,
-                                        bool honourHiDPI)
+                                        Common::Size size, bool honourHiDPI)
 {
-  // always save, maybe only the mode of the window has changed
-  saveCurrentWindowPosition();
-  myBufferType = type;
-
   ++myInitializedCount;
-  myScreenTitle = title;
+  myBackend->setTitle(title);
 
-  // In HiDPI mode, all created displays must be scaled by 2x
+  // In HiDPI mode, all created displays must be scaled appropriately
   if(honourHiDPI && hidpiEnabled())
   {
-    width  *= hidpiScaleFactor();
-    height *= hidpiScaleFactor();
+    size.w *= hidpiScaleFactor();
+    size.h *= hidpiScaleFactor();
   }
 
   // A 'windowed' system is defined as one where the window size can be
@@ -232,65 +238,35 @@ FBInitStatus FrameBuffer::createDisplay(const string& title, BufferType type,
   // If the WINDOWED_SUPPORT macro is defined, we treat the system as the
   // former type; if not, as the latter type
 
-  bool useFullscreen = false;
 #ifdef WINDOWED_SUPPORT
   // We assume that a desktop of at least minimum acceptable size means that
   // we're running on a 'large' system, and the window size requirements
   // can be relaxed
   // Otherwise, we treat the system as if WINDOWED_SUPPORT is not defined
   if(myDesktopSize.w < FBMinimum::Width && myDesktopSize.h < FBMinimum::Height &&
-    (myDesktopSize.w < width || myDesktopSize.h < height))
+     size > myDesktopSize)
     return FBInitStatus::FailTooLarge;
-
-  useFullscreen = myOSystem.settings().getBool("fullscreen");
 #else
   // Make sure this mode is even possible
   // We only really need to worry about it in non-windowed environments,
   // where requesting a window that's too large will probably cause a crash
-  if(myDesktopSize.w < width || myDesktopSize.h < height)
+  if(size > myDesktopSize)
     return FBInitStatus::FailTooLarge;
-
-  useFullscreen = true;
 #endif
 
-  // Set the available video modes for this framebuffer
-  setAvailableVidModes(width, height);
+  // Initialize video mode handler, so it can know what video modes are
+  // appropriate for the requested image size
+  myVidModeHandler.setImageSize(size);
 
-  // Initialize video subsystem (make sure we get a valid mode)
-  string pre_about = about();
-  const FrameBuffer::VideoMode& mode = getSavedVidMode(useFullscreen);
-  if(width <= mode.screen.w && height <= mode.screen.h)
-  {
-    // Changing the video mode can take some time, during which the last
-    // sound played may get 'stuck'
-    // So we mute the sound until the operation completes
-    bool oldMuteState = myOSystem.sound().mute(true);
-    if(setVideoMode(myScreenTitle, mode))
-    {
-      myImageRect = mode.image;
-      myScreenSize = mode.screen;
-      myScreenRect = Common::Rect(mode.screen);
+  // Always save, maybe only the mode of the window has changed
+  saveCurrentWindowPosition();
+  myBufferType = type;
 
-      // Inform TIA surface about new mode
-      if(myOSystem.eventHandler().state() != EventHandlerState::LAUNCHER &&
-         myOSystem.eventHandler().state() != EventHandlerState::DEBUGGER)
-        myTIASurface->initialize(myOSystem.console(), mode);
-
-      // Did we get the requested fullscreen state?
-      myOSystem.settings().setValue("fullscreen", fullScreen());
-      resetSurfaces();
-      setCursorState();
-
-      myOSystem.sound().mute(oldMuteState);
-    }
-    else
-    {
-      Logger::error("ERROR: Couldn't initialize video subsystem");
-      return FBInitStatus::FailNotSupported;
-    }
-  }
-  else
-    return FBInitStatus::FailTooLarge;
+  // Initialize video subsystem
+  string pre_about = myBackend->about();
+  FBInitStatus status = applyVideoMode();
+  if(status != FBInitStatus::Success)
+    return status;
 
 #ifdef GUI_SUPPORT
   // Erase any messages from a previous run
@@ -322,16 +298,16 @@ FBInitStatus FrameBuffer::createDisplay(const string& title, BufferType type,
   // Print initial usage message, but only print it later if the status has changed
   if(myInitializedCount == 1)
   {
-    Logger::info(about());
+    Logger::info(myBackend->about());
   }
   else
   {
-    string post_about = about();
+    string post_about = myBackend->about();
     if(post_about != pre_about)
       Logger::info(post_about);
   }
 
-  return FBInitStatus::Success;
+  return status;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -453,11 +429,7 @@ void FrameBuffer::update(bool force)
       if (!success)
       {
         frames = 0;
-      #ifdef GUI_SUPPORT
         myOSystem.eventHandler().enterMenuMode(EventHandlerState::TIMEMACHINE);
-      #else
-        myOSystem.eventHandler().changeStateByEvent(Event::TogglePauseMode);
-      #endif
       }
       break;  // EventHandlerState::PLAYBACK
     }
@@ -500,7 +472,7 @@ void FrameBuffer::update(bool force)
 
   // Push buffers to screen only when necessary
   if(force)
-    renderToScreen();
+    myBackend->renderToScreen();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -526,7 +498,7 @@ void FrameBuffer::updateInEmulationMode(float framesPerSecond)
     drawMessage();
 
   // Push buffers to screen
-  renderToScreen();
+  myBackend->renderToScreen();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -633,7 +605,8 @@ void FrameBuffer::drawFrameStats(float framesPerSecond)
   ss
     << myOSystem.console().tia().frameBufferScanlinesLastFrame()
     << " / "
-    << std::fixed << std::setprecision(1) << myOSystem.console().getFramerate()
+    << std::fixed << std::setprecision(1)
+    << myOSystem.console().currentFrameRate()
     << "Hz => "
     << info.DisplayFormat;
 
@@ -664,7 +637,7 @@ void FrameBuffer::drawFrameStats(float framesPerSecond)
   myStatsMsg.surface->drawString(f, ss.str(), xPos, yPos,
       myStatsMsg.w, myStatsMsg.color, TextAlign::Left, 0, true, kBGColor);
 
-  myStatsMsg.surface->setDstPos(myImageRect.x() + 10, myImageRect.y() + 8);
+  myStatsMsg.surface->setDstPos(imageRect().x() + 10, imageRect().y() + 8);
   myStatsMsg.surface->setDstSize(myStatsMsg.w * hidpiScaleFactor(),
                                  myStatsMsg.h * hidpiScaleFactor());
   myStatsMsg.surface->render();
@@ -742,47 +715,47 @@ inline bool FrameBuffer::drawMessage()
       break;
 
     case MessagePosition::TopCenter:
-      myMsg.x = (myImageRect.w() - dst.w()) >> 1;
+      myMsg.x = (imageRect().w() - dst.w()) >> 1;
       myMsg.y = 5;
       break;
 
     case MessagePosition::TopRight:
-      myMsg.x = myImageRect.w() - dst.w() - 5;
+      myMsg.x = imageRect().w() - dst.w() - 5;
       myMsg.y = 5;
       break;
 
     case MessagePosition::MiddleLeft:
       myMsg.x = 5;
-      myMsg.y = (myImageRect.h() - dst.h()) >> 1;
+      myMsg.y = (imageRect().h() - dst.h()) >> 1;
       break;
 
     case MessagePosition::MiddleCenter:
-      myMsg.x = (myImageRect.w() - dst.w()) >> 1;
-      myMsg.y = (myImageRect.h() - dst.h()) >> 1;
+      myMsg.x = (imageRect().w() - dst.w()) >> 1;
+      myMsg.y = (imageRect().h() - dst.h()) >> 1;
       break;
 
     case MessagePosition::MiddleRight:
-      myMsg.x = myImageRect.w() - dst.w() - 5;
-      myMsg.y = (myImageRect.h() - dst.h()) >> 1;
+      myMsg.x = imageRect().w() - dst.w() - 5;
+      myMsg.y = (imageRect().h() - dst.h()) >> 1;
       break;
 
     case MessagePosition::BottomLeft:
       myMsg.x = 5;
-      myMsg.y = myImageRect.h() - dst.h() - 5;
+      myMsg.y = imageRect().h() - dst.h() - 5;
       break;
 
     case MessagePosition::BottomCenter:
-      myMsg.x = (myImageRect.w() - dst.w()) >> 1;
-      myMsg.y = myImageRect.h() - dst.h() - 5;
+      myMsg.x = (imageRect().w() - dst.w()) >> 1;
+      myMsg.y = imageRect().h() - dst.h() - 5;
       break;
 
     case MessagePosition::BottomRight:
-      myMsg.x = myImageRect.w() - dst.w() - 5;
-      myMsg.y = myImageRect.h() - dst.h() - 5;
+      myMsg.x = imageRect().w() - dst.w() - 5;
+      myMsg.y = imageRect().h() - dst.h() - 5;
       break;
   }
 
-  myMsg.surface->setDstPos(myMsg.x + myImageRect.x(), myMsg.y + myImageRect.y());
+  myMsg.surface->setDstPos(myMsg.x + imageRect().x(), myMsg.y + imageRect().y());
   myMsg.surface->fillRect(0, 0, myMsg.w, myMsg.h, kColor);
   myMsg.surface->fillRect(BORDER, BORDER, myMsg.w - BORDER * 2, myMsg.h - BORDER * 2, kBtnColor);
   myMsg.surface->drawString(font(), myMsg.text, HBORDER, VBORDER,
@@ -835,11 +808,12 @@ void FrameBuffer::setPauseDelay()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-shared_ptr<FBSurface> FrameBuffer::allocateSurface(int w, int h, ScalingInterpolation interpolation,
-                                                   const uInt32* data)
+shared_ptr<FBSurface> FrameBuffer::allocateSurface(
+    int w, int h, ScalingInterpolation inter, const uInt32* data
+)
 {
   // Add new surface to the list
-  mySurfaceList.push_back(createSurface(w, h, interpolation, data));
+  mySurfaceList.push_back(myBackend->createSurface(w, h, inter, data));
 
   // And return a pointer to it (pointer should be treated read-only)
   return mySurfaceList.at(mySurfaceList.size() - 1);
@@ -977,9 +951,11 @@ string FrameBuffer::getPositionKey()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void FrameBuffer::saveCurrentWindowPosition()
 {
-  myOSystem.settings().setValue(getDisplayKey(), getCurrentDisplayIndex());
-  if(isCurrentWindowPositioned())
-    myOSystem.settings().setValue(getPositionKey(), getCurrentWindowPos());
+  myOSystem.settings().setValue(
+      getDisplayKey(), myBackend->getCurrentDisplayIndex());
+  if(myBackend->isCurrentWindowPositioned())
+    myOSystem.settings().setValue(
+        getPositionKey(), myBackend->getCurrentWindowPos());
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -1004,38 +980,17 @@ void FrameBuffer::setFullscreen(bool enable)
     default:
       return;
   }
+
+  myOSystem.settings().setValue("fullscreen", enable);
   saveCurrentWindowPosition();
-
-  // Changing the video mode can take some time, during which the last
-  // sound played may get 'stuck'
-  // So we mute the sound until the operation completes
-  bool oldMuteState = myOSystem.sound().mute(true);
-
-  const VideoMode& mode = getSavedVidMode(enable);
-  if(setVideoMode(myScreenTitle, mode))
-  {
-    myImageRect = mode.image;
-    myScreenSize = mode.screen;
-    myScreenRect = Common::Rect(mode.screen);
-
-    // Inform TIA surface about new mode
-    if(myOSystem.eventHandler().state() != EventHandlerState::LAUNCHER &&
-       myOSystem.eventHandler().state() != EventHandlerState::DEBUGGER)
-      myTIASurface->initialize(myOSystem.console(), mode);
-
-    // Did we get the requested fullscreen state?
-    myOSystem.settings().setValue("fullscreen", fullScreen());
-    resetSurfaces();
-    setCursorState();
-  }
-  myOSystem.sound().mute(oldMuteState);
+  applyVideoMode();
 #endif
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void FrameBuffer::toggleFullscreen(bool toggle)
 {
-  switch (myOSystem.eventHandler().state())
+  switch(myOSystem.eventHandler().state())
   {
     case EventHandlerState::LAUNCHER:
     case EventHandlerState::EMULATION:
@@ -1043,18 +998,17 @@ void FrameBuffer::toggleFullscreen(bool toggle)
     case EventHandlerState::DEBUGGER:
     {
       const bool isFullscreen = toggle ? !fullScreen() : fullScreen();
-
       setFullscreen(isFullscreen);
 
-      if (myBufferType != BufferType::Launcher)
+      if(myBufferType != BufferType::Launcher)
       {
         ostringstream msg;
-
         msg << "Fullscreen ";
-        if (isFullscreen)
-          msg << "enabled (" << refreshRate() << " Hz)";
+        if(isFullscreen)
+          msg << "enabled (" << myBackend->refreshRate() << " Hz, ";
         else
-          msg << "disabled";
+          msg << "disabled (";
+        msg << "Zoom " << myActiveVidMode.zoom * 100 << "%)";
 
         showMessage(msg.str());
       }
@@ -1087,7 +1041,7 @@ void FrameBuffer::toggleAdaptRefresh(bool toggle)
 
     msg << "Adapt refresh rate ";
     msg << (isAdaptRefresh ? "enabled" : "disabled");
-    msg << " (" << refreshRate() << " Hz)";
+    msg << " (" << myBackend->refreshRate() << " Hz)";
 
     showMessage(msg.str());
   }
@@ -1120,54 +1074,121 @@ void FrameBuffer::changeOverscan(int direction)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void FrameBuffer::selectVidMode(int direction)
+void FrameBuffer::switchVideoMode(int direction)
 {
-  EventHandlerState state = myOSystem.eventHandler().state();
-  bool tiaMode = (state != EventHandlerState::DEBUGGER &&
-                  state != EventHandlerState::LAUNCHER);
-
   // Only applicable when in TIA/emulation mode
-  if(!tiaMode)
+  if(!myOSystem.eventHandler().inTIAMode())
     return;
 
-  if(direction == +1)
-    myCurrentModeList->next();
-  else if(direction == -1)
-    myCurrentModeList->previous();
+  if(!fullScreen())
+  {
+    // Windowed TIA modes support variable zoom levels
+    float zoom = myOSystem.settings().getFloat("tia.zoom");
+    if(direction == +1)       zoom += ZOOM_STEPS;
+    else if(direction == -1)  zoom -= ZOOM_STEPS;
+
+    // Make sure the level is within the allowable desktop size
+    zoom = BSPF::clampw(zoom, supportedTIAMinZoom(), myTIAMaxZoom);
+    myOSystem.settings().setValue("tia.zoom", zoom);
+  }
+  else
+  {
+    // In fullscreen mode, there are only two modes, so direction
+    // is irrelevant
+    if(direction == +1 || direction == -1)
+    {
+      bool stretch = myOSystem.settings().getBool("tia.fs_stretch");
+      myOSystem.settings().setValue("tia.fs_stretch", !stretch);
+    }
+  }
 
   saveCurrentWindowPosition();
+  if(applyVideoMode() == FBInitStatus::Success)
+  {
+    if(fullScreen())
+      showMessage(myActiveVidMode.description);
+    else
+      showMessage("Zoom", myActiveVidMode.description, myActiveVidMode.zoom,
+                  supportedTIAMinZoom(), myTIAMaxZoom);
+  }
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+FBInitStatus FrameBuffer::applyVideoMode()
+{
+  // Update display size, in case windowed/fullscreen mode has changed
+  const Settings& s = myOSystem.settings();
+  if(s.getBool("fullscreen"))
+  {
+    Int32 fsIndex = std::max(myBackend->getCurrentDisplayIndex(), 0);
+    myVidModeHandler.setDisplaySize(myFullscreenDisplays[fsIndex], fsIndex);
+  }
+  else
+    myVidModeHandler.setDisplaySize(myAbsDesktopSize);
+
+  const bool inTIAMode = myOSystem.eventHandler().inTIAMode();
+
+  // Build the new mode based on current settings
+  const VideoModeHandler::Mode& mode = myVidModeHandler.buildMode(s, inTIAMode);
+  if(mode.imageR.size() > mode.screenS)
+    return FBInitStatus::FailTooLarge;
 
   // Changing the video mode can take some time, during which the last
   // sound played may get 'stuck'
   // So we mute the sound until the operation completes
   bool oldMuteState = myOSystem.sound().mute(true);
+  FBInitStatus status = FBInitStatus::FailNotSupported;
 
-  const VideoMode& mode = myCurrentModeList->current();
-  if(setVideoMode(myScreenTitle, mode))
+  if(myBackend->setVideoMode(mode,
+      myOSystem.settings().getInt(getDisplayKey()),
+      myOSystem.settings().getPoint(getPositionKey()))
+    )
   {
-    myImageRect = mode.image;
-    myScreenSize = mode.screen;
-    myScreenRect = Common::Rect(mode.screen);
+    myActiveVidMode = mode;
+    status = FBInitStatus::Success;
 
-    // Inform TIA surface about new mode
-    myTIASurface->initialize(myOSystem.console(), mode);
+    // Did we get the requested fullscreen state?
+    myOSystem.settings().setValue("fullscreen", fullScreen());
+
+    // Inform TIA surface about new mode, and update TIA settings
+    if(inTIAMode)
+    {
+      myTIASurface->initialize(myOSystem.console(), myActiveVidMode);
+      if(fullScreen())
+        myOSystem.settings().setValue("tia.fs_stretch",
+          myActiveVidMode.stretch == VideoModeHandler::Mode::Stretch::Fill);
+      else
+        myOSystem.settings().setValue("tia.zoom", myActiveVidMode.zoom);
+    }
 
     resetSurfaces();
-    if(fullScreen())
-      showMessage(mode.description);
-    else
-      showMessage("Zoom", mode.description, mode.zoom, supportedTIAMinZoom(), myTIAMaxZoom);
-    myOSystem.sound().mute(oldMuteState);
-
-    if(fullScreen())
-      myOSystem.settings().setValue("tia.fs_stretch",
-          mode.stretch == VideoMode::Stretch::Fill);
-    else
-      myOSystem.settings().setValue("tia.zoom", mode.zoom);
-
-    return;
+    setCursorState();
   }
+  else
+    Logger::error("ERROR: Couldn't initialize video subsystem");
+
+  // Restore sound settings
   myOSystem.sound().mute(oldMuteState);
+
+  return status;
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+float FrameBuffer::maxWindowZoom(uInt32 baseWidth, uInt32 baseHeight) const
+{
+  float multiplier = 1;
+  for(;;)
+  {
+    // Figure out the zoomed size of the window
+    uInt32 width  = baseWidth * multiplier;
+    uInt32 height = baseHeight * multiplier;
+
+    if((width > myAbsDesktopSize.w) || (height > myAbsDesktopSize.h))
+      break;
+
+    multiplier += ZOOM_STEPS;
+  }
+  return multiplier > 1 ? multiplier - ZOOM_STEPS : 1;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -1209,7 +1230,7 @@ void FrameBuffer::setCursorState()
       break;
   }
 
-  grabMouse(emulation && (analog || alwaysUseMouse) && myGrabMouse);
+  myBackend->grabMouse(emulation && (analog || alwaysUseMouse) && myGrabMouse);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -1232,296 +1253,6 @@ void FrameBuffer::toggleGrabMouse()
                                       : "Grab mouse not allowed while cursor shown");
 }
 
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-float FrameBuffer::maxZoomForScreen(uInt32 baseWidth, uInt32 baseHeight,
-                                    uInt32 screenWidth, uInt32 screenHeight) const
-{
-  float multiplier = 1;
-  for(;;)
-  {
-    // Figure out the zoomed size of the window
-    uInt32 width  = baseWidth * multiplier;
-    uInt32 height = baseHeight * multiplier;
-
-    if((width > screenWidth) || (height > screenHeight))
-      break;
-
-    multiplier += ZOOM_STEPS;
-  }
-  return multiplier > 1 ? multiplier - ZOOM_STEPS : 1;
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void FrameBuffer::setAvailableVidModes(uInt32 baseWidth, uInt32 baseHeight)
-{
-  myWindowedModeList.clear();
-
-  for(auto& mode: myFullscreenModeLists)
-    mode.clear();
-  for(size_t i = myFullscreenModeLists.size(); i < myFullscreenDisplays.size(); ++i)
-    myFullscreenModeLists.emplace_back(VideoModeList());
-
-  // Check if zooming is allowed for this state (currently only allowed
-  // for TIA screens)
-  EventHandlerState state = myOSystem.eventHandler().state();
-  bool tiaMode = (state != EventHandlerState::DEBUGGER &&
-                  state != EventHandlerState::LAUNCHER);
-  float overscan = 1 - myOSystem.settings().getInt("tia.fs_overscan") / 100.0;
-
-  // TIA mode allows zooming at integral factors in windowed modes,
-  // and also non-integral factors in fullscreen mode
-  if(tiaMode)
-  {
-    // TIA windowed modes
-    float minZoom = supportedTIAMinZoom();
-    myTIAMaxZoom = maxZoomForScreen(baseWidth, baseHeight,
-                     myAbsDesktopSize.w, myAbsDesktopSize.h);
-    // Determine all zoom levels
-    for(float zoom = minZoom; zoom <= myTIAMaxZoom; zoom += ZOOM_STEPS)
-    {
-      ostringstream desc;
-      desc << (zoom * 100) << "%";
-
-      VideoMode mode(baseWidth*zoom, baseHeight*zoom, baseWidth*zoom, baseHeight*zoom,
-                     VideoMode::Stretch::Fill, 1.0, desc.str(), zoom);
-      myWindowedModeList.add(mode);
-    }
-
-    // TIA fullscreen mode
-    for(uInt32 i = 0; i < myFullscreenDisplays.size(); ++i)
-    {
-      myTIAMaxZoom = maxZoomForScreen(baseWidth, baseHeight,
-          myFullscreenDisplays[i].w * overscan,
-          myFullscreenDisplays[i].h * overscan);
-
-      // Add both normal aspect and filled modes
-      // It's easier to define them both now, and simply switch between
-      // them when necessary
-      VideoMode mode1(baseWidth * myTIAMaxZoom, baseHeight * myTIAMaxZoom,
-                      myFullscreenDisplays[i].w, myFullscreenDisplays[i].h,
-                      VideoMode::Stretch::Preserve, overscan,
-                      "Fullscreen: Preserve aspect, no stretch", myTIAMaxZoom, i);
-      myFullscreenModeLists[i].add(mode1);
-      VideoMode mode2(baseWidth * myTIAMaxZoom, baseHeight * myTIAMaxZoom,
-                      myFullscreenDisplays[i].w, myFullscreenDisplays[i].h,
-                      VideoMode::Stretch::Fill, overscan,
-                      "Fullscreen: Ignore aspect, full stretch", myTIAMaxZoom, i);
-      myFullscreenModeLists[i].add(mode2);
-    }
-  }
-  else  // UI mode
-  {
-    // Windowed and fullscreen mode differ only in screen size
-    myWindowedModeList.add(
-        VideoMode(baseWidth, baseHeight, baseWidth, baseHeight,
-        VideoMode::Stretch::None)
-    );
-    for(uInt32 i = 0; i < myFullscreenDisplays.size(); ++i)
-    {
-      myFullscreenModeLists[i].add(
-          VideoMode(baseWidth, baseHeight,
-                    myFullscreenDisplays[i].w, myFullscreenDisplays[i].h,
-                    VideoMode::Stretch::None, 1.0, "", 1, i)
-      );
-    }
-  }
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-const FrameBuffer::VideoMode& FrameBuffer::getSavedVidMode(bool fullscreen)
-{
-  if(fullscreen)
-  {
-    Int32 i = getCurrentDisplayIndex();
-    if(i < 0)
-    {
-      // default to the first display
-      i = 0;
-    }
-    myCurrentModeList = &myFullscreenModeLists[i];
-  }
-  else
-    myCurrentModeList = &myWindowedModeList;
-
-  // Now select the best resolution depending on the state
-  // UI modes (launcher and debugger) have only one supported resolution
-  // so the 'current' one is the only valid one
-  EventHandlerState state = myOSystem.eventHandler().state();
-  if(state == EventHandlerState::DEBUGGER || state == EventHandlerState::LAUNCHER)
-    myCurrentModeList->setByZoom(1);
-  else  // TIA mode
-  {
-    if(fullscreen)
-      myCurrentModeList->setByStretch(myOSystem.settings().getBool("tia.fs_stretch")
-        ? VideoMode::Stretch::Fill : VideoMode::Stretch::Preserve);
-    else
-      myCurrentModeList->setByZoom(myOSystem.settings().getFloat("tia.zoom"));
-  }
-
-  return myCurrentModeList->current();
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-//
-// VideoMode implementation
-//
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-FrameBuffer::VideoMode::VideoMode(uInt32 iw, uInt32 ih, uInt32 sw, uInt32 sh,
-                                  Stretch smode, float overscan, const string& desc,
-                                  float zoomLevel, Int32 fsindex)
-  : stretch(smode),
-    description(desc),
-    zoom(zoomLevel),
-    fsIndex(fsindex)
-{
-  // First set default size and positioning
-  sw = std::max(sw, TIAConstants::viewableWidth);
-  sh = std::max(sh, TIAConstants::viewableHeight);
-  iw = std::min(iw, sw);
-  ih = std::min(ih, sh);
-  int ix = (sw - iw) >> 1;
-  int iy = (sh - ih) >> 1;
-  image = Common::Rect(ix, iy, ix+iw, iy+ih);
-  screen = Common::Size(sw, sh);
-
-  // Now resize based on windowed/fullscreen mode and stretch factor
-  iw = image.w();
-  ih = image.h();
-
-  if(fsIndex != -1)
-  {
-    switch(stretch)
-    {
-      case Stretch::Preserve:
-      {
-        float stretchFactor = 1.0;
-        float scaleX = float(iw) / screen.w;
-        float scaleY = float(ih) / screen.h;
-
-        // Scale to all available space, keep aspect correct
-        if(scaleX > scaleY)
-          stretchFactor = float(screen.w) / iw;
-        else
-          stretchFactor = float(screen.h) / ih;
-
-        iw = uInt32(stretchFactor * iw) * overscan;
-        ih = uInt32(stretchFactor * ih) * overscan;
-        break;
-      }
-
-      case Stretch::Fill:
-        // Scale to all available space
-        iw = screen.w * overscan;
-        ih = screen.h * overscan;
-        break;
-
-      case Stretch::None:
-        // Don't do any scaling at all, but obey overscan
-        iw = std::min(iw, screen.w) * overscan;
-        ih = std::min(ih, screen.h) * overscan;
-        break;
-    }
-  }
-  else
-  {
-    // In windowed mode, currently the size is scaled to the screen
-    // TODO - this may be updated if/when we allow variable-sized windows
-    switch(stretch)
-    {
-      case Stretch::Preserve:
-      case Stretch::Fill:
-        screen.w = iw;
-        screen.h = ih;
-        break;
-      case Stretch::None:
-        break;  // Do not change image or screen rects whatsoever
-    }
-  }
-
-  // Now re-calculate the dimensions
-  iw = std::min(iw, screen.w);
-  ih = std::min(ih, screen.h);
-
-  image.moveTo((screen.w - iw) >> 1, (screen.h - ih) >> 1);
-  image.setWidth(iw);
-  image.setHeight(ih);
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-//
-// VideoModeList implementation
-//
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void FrameBuffer::VideoModeList::add(const VideoMode& mode)
-{
-  myModeList.emplace_back(mode);
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void FrameBuffer::VideoModeList::clear()
-{
-  myModeList.clear();
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool FrameBuffer::VideoModeList::empty() const
-{
-  return myModeList.empty();
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-uInt32 FrameBuffer::VideoModeList::size() const
-{
-  return uInt32(myModeList.size());
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void FrameBuffer::VideoModeList::previous()
-{
-  --myIdx;
-  if(myIdx < 0) myIdx = int(myModeList.size()) - 1;
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-const FrameBuffer::VideoMode& FrameBuffer::VideoModeList::current() const
-{
-  return myModeList[myIdx];
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void FrameBuffer::VideoModeList::next()
-{
-  myIdx = (myIdx + 1) % myModeList.size();
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void FrameBuffer::VideoModeList::setByZoom(float zoom)
-{
-  for(uInt32 i = 0; i < myModeList.size(); ++i)
-  {
-    if(myModeList[i].zoom == zoom)
-    {
-      myIdx = i;
-      return;
-    }
-  }
-  myIdx = 0;
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void FrameBuffer::VideoModeList::setByStretch(FrameBuffer::VideoMode::Stretch stretch)
-{
-  for(uInt32 i = 0; i < myModeList.size(); ++i)
-  {
-    if(myModeList[i].stretch == stretch)
-    {
-      myIdx = i;
-      return;
-    }
-  }
-  myIdx = 0;
-}
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 /*
   Palette is defined as follows:
