@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2019 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2020 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -23,11 +23,9 @@
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 Switches::Switches(const Event& event, const Properties& properties,
                    const Settings& settings)
-  : myEvent(event),
-    mySwitches(0xFF),
-    myIs7800(false)
+  : myEvent(event)
 {
-  if(properties.get(Console_RightDifficulty) == "B")
+  if(properties.get(PropType::Console_RightDiff) == "B")
   {
     mySwitches &= ~0x80;
   }
@@ -36,7 +34,7 @@ Switches::Switches(const Event& event, const Properties& properties,
     mySwitches |= 0x80;
   }
 
-  if(properties.get(Console_LeftDifficulty) == "B")
+  if(properties.get(PropType::Console_LeftDiff) == "B")
   {
     mySwitches &= ~0x40;
   }
@@ -45,7 +43,7 @@ Switches::Switches(const Event& event, const Properties& properties,
     mySwitches |= 0x40;
   }
 
-  if(properties.get(Console_TelevisionType) == "COLOR")
+  if(properties.get(PropType::Console_TVType) == "COLOR")
   {
     mySwitches |= 0x08;
   }
@@ -71,16 +69,14 @@ void Switches::update()
       mySwitches |= 0x08;
     }
   }
-  else
+
+  if(myEvent.get(Event::ConsoleColor) != 0)
   {
-    if(myEvent.get(Event::ConsoleColor) != 0)
-    {
-      mySwitches |= 0x08;
-    }
-    else if(myEvent.get(Event::ConsoleBlackWhite) != 0)
-    {
-      mySwitches &= ~0x08;
-    }
+    mySwitches |= 0x08;
+  }
+  else if(myEvent.get(Event::ConsoleBlackWhite) != 0)
+  {
+    mySwitches &= ~0x08;
   }
 
   if(myEvent.get(Event::ConsoleRightDiffA) != 0)
