@@ -27,19 +27,19 @@
 #include "TIASurface.hxx"
 
 namespace {
-  FrameBuffer::ScalingInterpolation interpolationModeFromSettings(const Settings& settings)
+  ScalingInterpolation interpolationModeFromSettings(const Settings& settings)
   {
 #ifdef RETRON77
   // Witv TV / and or scanline interpolation, the image has a height of ~480px. THe R77 runs at 720p, so there
   // is no benefit from QIS in y-direction. In addition, QIS on the R77 has performance issues if TV effects are
   // enabled.
   return settings.getBool("tia.inter") || settings.getInt("tv.filter") != 0
-    ? FrameBuffer::ScalingInterpolation::blur
-    : FrameBuffer::ScalingInterpolation::sharp;
+    ? ScalingInterpolation::blur
+    : ScalingInterpolation::sharp;
 #else
     return settings.getBool("tia.inter") ?
-      FrameBuffer::ScalingInterpolation::blur :
-      FrameBuffer::ScalingInterpolation::sharp;
+      ScalingInterpolation::blur :
+      ScalingInterpolation::sharp;
 #endif
   }
 }
@@ -57,7 +57,7 @@ TIASurface::TIASurface(OSystem& system)
     AtariNTSC::outWidth(TIAConstants::frameBufferWidth),
     TIAConstants::frameBufferHeight,
     !correctAspect()
-      ? FrameBuffer::ScalingInterpolation::none
+      ? ScalingInterpolation::none
       : interpolationModeFromSettings(myOSystem.settings())
   );
 
@@ -91,14 +91,14 @@ TIASurface::~TIASurface()
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void TIASurface::initialize(const Console& console,
-                            const FrameBuffer::VideoMode& mode)
+                            const VideoModeHandler::Mode& mode)
 {
   myTIA = &(console.tia());
 
-  myTiaSurface->setDstPos(mode.image.x(), mode.image.y());
-  myTiaSurface->setDstSize(mode.image.w(), mode.image.h());
-  mySLineSurface->setDstPos(mode.image.x(), mode.image.y());
-  mySLineSurface->setDstSize(mode.image.w(), mode.image.h());
+  myTiaSurface->setDstPos(mode.imageR.x(), mode.imageR.y());
+  myTiaSurface->setDstSize(mode.imageR.w(), mode.imageR.h());
+  mySLineSurface->setDstPos(mode.imageR.x(), mode.imageR.y());
+  mySLineSurface->setDstSize(mode.imageR.w(), mode.imageR.h());
 
   myPaletteHandler->setPalette();
 
@@ -167,7 +167,6 @@ uInt32 TIASurface::mapIndexedPixel(uInt8 indexedColor, uInt8 shift) const
   return myPalette[indexedColor | shift];
 }
 
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void TIASurface::setNTSC(NTSCFilter::Preset preset, bool show)
 {
@@ -512,13 +511,16 @@ void TIASurface::renderForSnapshot()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void TIASurface::updateSurfaceSettings()
 {
-  myTiaSurface->setScalingInterpolation(interpolationModeFromSettings(myOSystem.settings()));
+  myTiaSurface->setScalingInterpolation(
+      interpolationModeFromSettings(myOSystem.settings())
+  );
   mySLineSurface->setScalingInterpolation(
       interpolationModeFromSettings(myOSystem.settings())
   );
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool TIASurface::correctAspect() const {
+bool TIASurface::correctAspect() const
+{
   return myOSystem.settings().getBool("tia.correct_aspect");
 }
