@@ -20,6 +20,8 @@
 #include "Version.hxx"
 #include "Widget.hxx"
 #include "Font.hxx"
+#include "WhatsNewDialog.hxx"
+
 #include "AboutDialog.hxx"
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -64,11 +66,17 @@ AboutDialog::AboutDialog(OSystem& osystem, DialogContainer& parent,
   wid.push_back(b);
   addCancelWidget(b);
 
-  xpos = HBORDER;  ypos = _th + VBORDER;
+  xpos = HBORDER;  ypos = _th + VBORDER + (buttonHeight - fontHeight) / 2;
   myTitle = new StaticTextWidget(this, font, xpos, ypos, _w - xpos * 2, fontHeight,
                                  "", TextAlign::Center);
   myTitle->setTextColor(kTextColorEm);
 
+  int bwidth = font.getStringWidth("What's New" + ELLIPSIS) + fontWidth * 2.5;
+  myWhatsNewButton =
+    new ButtonWidget(this, font, _w - HBORDER - bwidth, ypos - (buttonHeight - fontHeight) / 2,
+                     bwidth, buttonHeight, "What's New" + ELLIPSIS, kWhatsNew);
+  wid.push_back(myWhatsNewButton);
+
   xpos = HBORDER * 2;  ypos += lineHeight + VGAP * 2;
   for(int i = 0; i < myLinesPerPage; i++)
   {
@@ -81,6 +89,11 @@ AboutDialog::AboutDialog(OSystem& osystem, DialogContainer& parent,
   addToFocusList(wid);
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+AboutDialog::~AboutDialog()
+{
+}
+
 // The following commands can be put at the start of a line (all subject to change):
 //   \C, \L, \R  -- set center/left/right alignment
 //   \c0 - \c5   -- set a custom color:
@@ -258,6 +271,13 @@ void AboutDialog::handleCommand(CommandSender* sender, int cmd, int data, int id
       displayInfo();
       break;
 
+    case kWhatsNew:
+      if(myWhatsNewDialog == nullptr)
+        myWhatsNewDialog = make_unique<WhatsNewDialog>(instance(), parent(), _font,
+                                                       640 * 0.95, 480 * 0.95);
+      myWhatsNewDialog->open();
+      break;
+
     default:
       Dialog::handleCommand(sender, cmd, data, 0);
   }
