@@ -19,11 +19,13 @@
 #include "StellaKeys.hxx"
 #include "FBSurface.hxx"
 #include "Font.hxx"
+#include "OSystem.hxx"
+#include "EventHandler.hxx"
 #include "EditableWidget.hxx"
 
-// Uncomment the following to give full-line copy/paste
-// Note that this will be removed eventually, when we implement proper copy/paste
-//#define PSEUDO_COPY_PASTE
+// Uncomment the following to give full-line cut/copy/paste
+// Note that this will be removed eventually, when we implement proper cut/copy/paste
+#define PSEUDO_CUT_COPY_PASTE
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 EditableWidget::EditableWidget(GuiObject* boss, const GUI::Font& font,
@@ -136,7 +138,13 @@ bool EditableWidget::handleKeyDown(StellaKey key, StellaMod mod)
 
     case KBDK_DELETE:
     case KBDK_KP_PERIOD:
-      dirty = killChar(+1);
+      if(StellaModTest::isShift(mod))
+      {
+        cutSelectedText();
+        dirty = true;
+      }
+      else
+        dirty = killChar(+1);
       if(dirty)  sendCommand(EditableWidget::kChangedCmd, key, _id);
       break;
 
@@ -162,6 +170,21 @@ bool EditableWidget::handleKeyDown(StellaKey key, StellaMod mod)
       dirty = setCaretPos(int(_editString.size()));
       break;
 
+    case KBDK_INSERT:
+      if(StellaModTest::isControl(mod))
+      {
+        copySelectedText();
+        dirty = true;
+      }
+      else if(StellaModTest::isShift(mod))
+      {
+        pasteSelectedText();
+        dirty = true;
+      }
+      else
+        handled = false;
+      break;
+
     default:
       if (StellaModTest::isControl(mod))
       {
@@ -260,7 +283,7 @@ bool EditableWidget::specialKeys(StellaKey key)
 {
   bool handled = true;
 
-  switch (key)
+  switch(key)
   {
     case KBDK_A:
       setCaretPos(0);
@@ -268,7 +291,6 @@ bool EditableWidget::specialKeys(StellaKey key)
 
     case KBDK_C:
       copySelectedText();
-      if(handled) sendCommand(EditableWidget::kChangedCmd, key, _id);
       break;
 
     case KBDK_E:
@@ -292,7 +314,7 @@ bool EditableWidget::specialKeys(StellaKey key)
 
     case KBDK_V:
       pasteSelectedText();
-      if(handled) sendCommand(EditableWidget::kChangedCmd, key, _id);
+      sendCommand(EditableWidget::kChangedCmd, key, _id);
       break;
 
     case KBDK_W:
@@ -300,6 +322,11 @@ bool EditableWidget::specialKeys(StellaKey key)
       if(handled) sendCommand(EditableWidget::kChangedCmd, key, _id);
       break;
 
+    case KBDK_X:
+      cutSelectedText();
+      sendCommand(EditableWidget::kChangedCmd, key, _id);
+      break;
+
     case KBDK_LEFT:
       handled = moveWord(-1);
       break;
@@ -445,21 +472,28 @@ bool EditableWidget::moveWord(int direction)
   return handled;
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void EditableWidget::cutSelectedText()
+{
+#if defined(PSEUDO_CUT_COPY_PASTE)
+  instance().eventHandler().cutText(_editString);
+  _caretPos = 0;
+#endif
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void EditableWidget::copySelectedText()
 {
-#if defined(PSEUDO_COPY_PASTE)
-  _clippedText = _editString;
+#if defined(PSEUDO_CUT_COPY_PASTE)
+  instance().eventHandler().copyText(_editString);
 #endif
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void EditableWidget::pasteSelectedText()
 {
-#if defined(PSEUDO_COPY_PASTE)
-  _editString = _clippedText;
+#if defined(PSEUDO_CUT_COPY_PASTE)
+  instance().eventHandler().pasteText(_editString);
+  _caretPos = int(_editString.length());
 #endif
 }
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-string EditableWidget::_clippedText = "";
