@@ -28,6 +28,7 @@
 #include "OptionsDialog.hxx"
 #include "GlobalPropsDialog.hxx"
 #include "StellaSettingsDialog.hxx"
+#include "WhatsNewDialog.hxx"
 #include "MessageBox.hxx"
 #include "OSystem.hxx"
 #include "FrameBuffer.hxx"
@@ -287,6 +288,14 @@ void LauncherDialog::loadConfig()
   const string& tmpromdir = instance().settings().getString("tmpromdir");
   const string& romdir = tmpromdir != "" ? tmpromdir :
       instance().settings().getString("romdir");
+  const string& version = instance().settings().getString("stella.version");
+
+  // Show "What's New" message when a new version of Stella is run for the first time
+  if(version != STELLA_VERSION)
+  {
+    openWhatsNew();
+    instance().settings().setValue("stella.version", STELLA_VERSION);
+  }
 
   // Assume that if the list is empty, this is the first time that loadConfig()
   // has been called (and we should reload the list)
@@ -617,11 +626,17 @@ void LauncherDialog::handleCommand(CommandSender* sender, int cmd,
 
     case kRomDirChosenCmd:
     {
-      FilesystemNode node(instance().settings().getString("romdir"));
-      if(!(node.exists() && node.isDirectory()))
-        node = FilesystemNode("~");
+      string romDir = instance().settings().getString("romdir");
 
-      myList->setDirectory(node);
+      if(myList->currentDir().getPath() != romDir)
+      {
+        FilesystemNode node(romDir);
+
+        if(!(node.exists() && node.isDirectory()))
+          node = FilesystemNode("~");
+
+        myList->setDirectory(node);
+      }
       break;
     }
 
@@ -659,6 +674,8 @@ void LauncherDialog::setDefaultDir()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void LauncherDialog::openSettings()
 {
+  saveConfig();
+
   // Create an options dialog, similar to the in-game one
   if (instance().settings().getBool("basic_settings"))
   {
@@ -675,3 +692,11 @@ void LauncherDialog::openSettings()
     myOptionsDialog->open();
   }
 }
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void LauncherDialog::openWhatsNew()
+{
+  if(myWhatsNewDialog == nullptr)
+    myWhatsNewDialog = make_unique<WhatsNewDialog>(instance(), parent(), _font, _w, _h);
+  myWhatsNewDialog->open();
+}
