@@ -195,6 +195,7 @@ void StellaSettingsDialog::addGameOptions(WidgetArray& wid, int& xpos, int& ypos
   VarList::push_back(ctrls, "AtariMouse", "ATARIMOUSE");
   VarList::push_back(ctrls, "Trakball", "TRAKBALL");
   VarList::push_back(ctrls, "Sega Genesis", "GENESIS");
+  VarList::push_back(ctrls, "QuadTari", "QUADTARI");
 
   int pwidth = _font.getStringWidth("Sega Genesis");
   myLeftPortLabel = new StaticTextWidget(this, _font, xpos, ypos + 1, "Left port  ");
@@ -540,7 +541,7 @@ void StellaSettingsDialog::updateControllerStates()
     if(instance().hasConsole())
       label = (instance().console().leftController().name()) + " detected";
     else if(autoDetect)
-      label = ControllerDetector::detectName(image.get(), size, type,
+      label = ControllerDetector::detectName(image, size, type,
                                              Controller::Jack::Left,
                                              instance().settings()) + " detected";
   }
@@ -554,7 +555,7 @@ void StellaSettingsDialog::updateControllerStates()
     if(instance().hasConsole())
       label = (instance().console().rightController().name()) + " detected";
     else if(autoDetect)
-      label = ControllerDetector::detectName(image.get(), size, type,
+      label = ControllerDetector::detectName(image, size, type,
                                              Controller::Jack::Right,
                                              instance().settings()) + " detected";
   }
