@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2019 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2020 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -24,16 +24,6 @@
   @author  Mark Grebe <atarimac@cox.net>
 */
 @interface AboutBox : NSObject
-{
-  IBOutlet NSTextField *appNameField;
-  IBOutlet NSTextView *creditsField;
-  IBOutlet NSTextField *versionField;
-  NSTimer *scrollTimer;
-  CGFloat currentPosition;
-  CGFloat maxScrollHeight;
-  NSTimeInterval startTime;
-  BOOL restartAtTop;
-}
 
 + (AboutBox *)sharedInstance;
 - (IBAction)showPanel:(id)sender;
