@@ -3,29 +3,33 @@ package PropSet;
 # NOTE: If the property types ever change in Stella, the following hashmap
 #       and array must be updated (and stay in sequence)
 my %prop_type = (
-  "Cart.MD5"                => 0,
-  "Cart.Manufacturer"       => 1,
-  "Cart.ModelNo"            => 2,
-  "Cart.Name"               => 3,
-  "Cart.Note"               => 4,
-  "Cart.Rarity"             => 5,
-  "Cart.Sound"              => 6,
-  "Cart.StartBank"          => 7,
-  "Cart.Type"               => 8,
-  "Console.LeftDiff"        => 9,
-  "Console.RightDiff"       => 10,
-  "Console.TVType"          => 11,
-  "Console.SwapPorts"       => 12,
-  "Controller.Left"         => 13,
-  "Controller.Right"        => 14,
-  "Controller.SwapPaddles"  => 15,
-  "Controller.PaddlesXCenter" => 16,
-  "Controller.PaddlesYCenter" => 17,  
-  "Controller.MouseAxis"    => 18,
-  "Display.Format"          => 19,
-  "Display.VCenter"         => 20,
-  "Display.Phosphor"        => 21,
-  "Display.PPBlend"         => 22
+  "Cart.MD5"                  => 0,
+  "Cart.Manufacturer"         => 1,
+  "Cart.ModelNo"              => 2,
+  "Cart.Name"                 => 3,
+  "Cart.Note"                 => 4,
+  "Cart.Rarity"               => 5,
+  "Cart.Sound"                => 6,
+  "Cart.StartBank"            => 7,
+  "Cart.Type"                 => 8,
+  "Console.LeftDiff"          => 9,
+  "Console.RightDiff"         => 10,
+  "Console.TVType"            => 11,
+  "Console.SwapPorts"         => 12,
+  "Controller.Left"           => 13,
+  "Controller.Left1"          => 14,
+  "Controller.Left2"          => 15,
+  "Controller.Right"          => 16,
+  "Controller.Right1"         => 17,
+  "Controller.Right2"         => 18,
+  "Controller.SwapPaddles"    => 19,
+  "Controller.PaddlesXCenter" => 20,
+  "Controller.PaddlesYCenter" => 21,
+  "Controller.MouseAxis"      => 22,
+  "Display.Format"            => 23,
+  "Display.VCenter"           => 24,
+  "Display.Phosphor"          => 25,
+  "Display.PPBlend"           => 26
 );
 my @prop_type_as_string = (
   "Cart.MD5",
@@ -42,7 +46,11 @@ my @prop_type_as_string = (
   "Console.TVType",
   "Console.SwapPorts",
   "Controller.Left",
+  "Controller.Left1",
+  "Controller.Left2",
   "Controller.Right",
+  "Controller.Right1",
+  "Controller.Right2",
   "Controller.SwapPaddles",
   "Controller.PaddlesXCenter",
   "Controller.PaddlesYCenter",
@@ -69,7 +77,13 @@ my @prop_defaults = (
   "NO",
   "",
   "",
+  "",
+  "",
+  "",
+  "",
   "NO",
+  "0",
+  "0",
   "AUTO",
   "AUTO",
   "0",
